@@ -1,22 +1,10 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
-   Copyright (C) 2007 Flavio Castelli <flavio.castelli@gmail.com>
+   SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+   SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+   SPDX-FileCopyrightText: 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
+   SPDX-FileCopyrightText: 2007 Flavio Castelli <flavio.castelli@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 // BEGIN Includes
@@ -37,24 +25,21 @@
 #include "katesessionmanager.h"
 #include "katesessionsaction.h"
 #include "kateupdatedisabler.h"
-#include "kateviewmanager.h"
 #include "kateviewspace.h"
 
-#include <KAboutApplicationDialog>
 #include <KAboutData>
 #include <KActionCollection>
 #include <KActionMenu>
+#include <KApplicationTrader>
 #include <KConfigGroup>
 #include <KEditToolBar>
 #include <KHelpClient>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KMimeTypeTrader>
 #include <KMultiTabBar>
 #include <KOpenWithDialog>
 #include <KRecentDocument>
 #include <KRecentFilesAction>
-#include <KRun>
 #include <KSharedConfig>
 #include <KShortcutsDialog>
 #include <KStandardAction>
@@ -64,15 +49,20 @@
 #include <KWindowSystem>
 #include <KXMLGUIFactory>
 
+#include <kio_version.h>
+#if KIO_VERSION < QT_VERSION_CHECK(5, 71, 0)
+#include <KRun>
+#else
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegate>
+#endif
+
 #include <KFileItem>
 #include <KIO/Job>
 
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QDir>
-#include <QDragEnterEvent>
-#include <QDropEvent>
-#include <QEvent>
 #include <QFontDatabase>
 #include <QList>
 #include <QMenu>
@@ -420,10 +410,6 @@ void KateMainWindow::setupActions()
         a->setWhatsThis(i18n("This shows help files for various available plugins."));
     }
 
-    a = actionCollection()->addAction(QStringLiteral("help_about_editor"));
-    a->setText(i18n("&About Editor Component"));
-    connect(a, &QAction::triggered, this, &KateMainWindow::aboutEditor);
-
     connect(m_viewManager, &KateViewManager::viewChanged, this, &KateMainWindow::slotWindowActivated);
     connect(m_viewManager, &KateViewManager::viewChanged, this, &KateMainWindow::slotUpdateOpenWith);
     connect(m_viewManager, &KateViewManager::viewChanged, this, &KateMainWindow::slotUpdateActionsNeedingUrl);
@@ -439,7 +425,7 @@ void KateMainWindow::setupActions()
     // session actions
     a = actionCollection()->addAction(QStringLiteral("sessions_new"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
-    a->setText(i18nc("Menu entry Session->New", "&New"));
+    a->setText(i18nc("Menu entry Session->New Session", "&New Session"));
     // Qt::QueuedConnection to avoid deletion of code that is executed when reducing the amount of mainwindows. (bug #227008)
     connect(a, &QAction::triggered, KateApp::self()->sessionManager(), &KateSessionManager::sessionNew, Qt::QueuedConnection);
     a = actionCollection()->addAction(QStringLiteral("sessions_save"));
@@ -853,7 +839,7 @@ bool KateMainWindow::showPluginConfigPage(KTextEditor::Plugin *configpageinterfa
         return false;
     }
 
-    KateConfigDialog *dlg = new KateConfigDialog(this, m_viewManager->activeView());
+    KateConfigDialog *dlg = new KateConfigDialog(this);
     if (configpageinterface) {
         dlg->showAppPluginPage(configpageinterface, id);
     }
@@ -901,7 +887,7 @@ void KateMainWindow::mSlotFixOpenWithMenu()
     // qCDebug(LOG_KATE) << "mime type: " << mime.name();
 
     QAction *a = nullptr;
-    const KService::List offers = KMimeTypeTrader::self()->query(mime.name(), QStringLiteral("Application"));
+    const KService::List offers = KApplicationTrader::queryByMimeType(mime.name());
     // add all default open-with-actions except "Kate"
     for (const auto &service : offers) {
         if (service->name() == QLatin1String("Kate")) {
@@ -917,8 +903,8 @@ void KateMainWindow::mSlotFixOpenWithMenu()
 
 void KateMainWindow::slotOpenWithMenuAction(QAction *a)
 {
-    QList<QUrl> list;
-    list.append(m_viewManager->activeView()->document()->url());
+    const QList<QUrl> list({m_viewManager->activeView()->document()->url()});
+#if KIO_VERSION < QT_VERSION_CHECK(5, 71, 0)
 
     const QString openWith = a->data().toString();
     if (openWith.isEmpty()) {
@@ -936,6 +922,14 @@ void KateMainWindow::slotOpenWithMenuAction(QAction *a)
     } else {
         KMessageBox::error(this, i18n("Application '%1' not found.", openWith), i18n("Application not found"));
     }
+#else
+    KService::Ptr app = KService::serviceByDesktopPath(a->data().toString());
+    // If app is null, ApplicationLauncherJob will invoke the open-with dialog
+    auto *job = new KIO::ApplicationLauncherJob(app);
+    job->setUrls(list);
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->start();
+#endif
 }
 
 void KateMainWindow::pluginHelp()
@@ -943,12 +937,6 @@ void KateMainWindow::pluginHelp()
     KHelpClient::invokeHelp(QString(), QStringLiteral("kate-plugins"));
 }
 
-void KateMainWindow::aboutEditor()
-{
-    KAboutApplicationDialog ad(KTextEditor::Editor::instance()->aboutData(), this);
-    ad.exec();
-}
-
 void KateMainWindow::slotFullScreen(bool t)
 {
     KToggleFullScreenAction::setFullScreen(this, t);
@@ -1106,7 +1094,6 @@ void KateMainWindow::saveWindowConfig(const KConfigGroup &_config)
 {
     KConfigGroup config(_config);
     saveMainWindowSettings(config);
-    KWindowConfig::saveWindowSize(windowHandle(), config);
     config.writeEntry("WindowState", static_cast<int>(windowState()));
     config.sync();
 }
@@ -1115,7 +1102,6 @@ void KateMainWindow::restoreWindowConfig(const KConfigGroup &config)
 {
     setWindowState(Qt::WindowNoState);
     applyMainWindowSettings(config);
-    KWindowConfig::restoreWindowSize(windowHandle(), config);
     setWindowState(QFlags<Qt::WindowState>(config.readEntry("WindowState", int(Qt::WindowActive))));
 }
 
